AppInfoProvider class

Properties

appName String
no setter
appVersion String
no setter
deviceId String
no setter
hashCode int
The hash code for this object.
no setterinherited
packageName String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getHeaders() Map<String, String>
initialize() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance AppInfoProvider
no setter