littlefish_core_utils library

Classes

AppInfoProvider
BusinessSystemValuesServiceImpl
Concrete implementation of BusinessSystemValuesService that talks to the BusinessController endpoints (GetBusinessValue / SetBusinessValue).
LittleFishHttpClient

Typedefs

AuthUserProvider = AuthUser? Function()
Function that returns the current authenticated user for HTTP requests.
BaseUrlProvider = String Function()
Function that returns the current base URL for API requests. Used to resolve the URL lazily so that it reflects the correct value even when the service is registered before configuration is loaded.